antares.apps.accounting.migrations package — Antares 0.0.2 documentation

# antares.apps.accounting.migrations package

## Submodules

## antares.apps.accounting.migrations.0001_initial module

## antares.apps.accounting.migrations.0002_auto_20180624_1759 module

## antares.apps.accounting.migrations.0003_auto_20190629_1936 module

class `antares.apps.accounting.migrations.0003_auto_20190629_1936.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('accounting', '0002_auto_20180624_1759')]
  `operations` = [<AlterField model_name='glaccounttype', name='level', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='glaccounttype', name='lft', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='glaccounttype', name='rght', field=<django.db.models.fields.PositiveIntegerField>>]

## antares.apps.accounting.migrations.0004_auto_20200131_0956 module

## antares.apps.accounting.migrations.0005_auto_20200131_1445 module

## antares.apps.accounting.migrations.0006_auto_20200131_1446 module

## antares.apps.accounting.migrations.0007_interestdefinition_penaltydefinition module

## Module contents